@@ -646,40 +646,36 @@ function check_error(integrator::DEIntegrator)
              true))
             if verbose isa Bool 
                 if isdefined(integrator, :EEst)
-                    EEst = ", and step error estimate = $(integrator.EEst)"
+                    EEst = lazy", and step error estimate = $(integrator.EEst)"
                 else
                     EEst = ""
                 end
-                @warn "dt($(integrator.dt)) <= dtmin($(opts.dtmin)) at t=$(integrator.t)$EEst. Aborting. There is either an error in your model specification or the true solution is unstable."
-            else   
-                @SciMLMessage(verbose, :dt_min_unstable) do 
-                    if isdefined(integrator, :EEst)
-                        EEst = ", and step error estimate = $(integrator.EEst)"
-                    else
-                        EEst = ""
-                    end
-                    "dt($(integrator.dt)) <= dtmin($(opts.dtmin)) at t=$(integrator.t)$EEst. Aborting. There is either an error in your model specification or the true solution is unstable."
-                end 
+                @warn lazy"dt($(integrator.dt)) <= dtmin($(opts.dtmin)) at t=$(integrator.t)$EEst. Aborting. There is either an error in your model specification or the true solution is unstable."
+            else
+                EEst = if isdefined(integrator, :EEst)
+                    lazy", and step error estimate = $(integrator.EEst)"
+                else
+                    ""
+                end
+                @SciMLMessage(lazy"dt($(integrator.dt) <= dtmin($(opts.dtmin)), at t=$(integrator.t)$EEst. Aborting. There is either an error in your model specification or the true solution is unstable.", verbose, :dt_min_unstable)
             end
             return ReturnCode.DtLessThanMin
         elseif !step_accepted && integrator.t isa AbstractFloat &&
                abs(integrator.dt) <= abs(eps(integrator.t))
             if verbose isa Bool 
                 if isdefined(integrator, :EEst)
-                    EEst = ", and step error estimate = $(integrator.EEst)"
+                    EEst = lazy", and step error estimate = $(integrator.EEst)"
                 else
                     EEst = ""
                 end
-                @warn "At t=$(integrator.t), dt was forced below floating point epsilon $(integrator.dt)$EEst. Aborting. There is either an error in your model specification or the true solution is unstable (or the true solution can not be represented in the precision of $(eltype(integrator.u)))."
+                @warn lazy"At t=$(integrator.t), dt was forced below floating point epsilon $(integrator.dt)$EEst. Aborting. There is either an error in your model specification or the true solution is unstable (or the true solution can not be represented in the precision of $(eltype(integrator.u)))."
             else
-                @SciMLMessage(verbose, :dt_epsilon) do 
-                    if isdefined(integrator, :EEst)
-                        EEst = ", and step error estimate = $(integrator.EEst)"
-                    else
-                        EEst = ""
-                    end
-                    "At t=$(integrator.t), dt was forced below floating point epsilon $(integrator.dt)$EEst. Aborting. There is either an error in your model specification or the true solution is unstable (or the true solution can not be represented in the precision of $(eltype(integrator.u)))."
+                EEst = if isdefined(integrator, :EEst)
+                    lazy", and step error estimate = $(integrator.EEst)"
+                else
+                    ""
                 end
+                @SciMLMessage(lazy"At t= $(integrator.t), dt was forced below floating point epsilon $(integrator.dt)$EEst. Aborting. There is either an error in your model specification or the true solution is unstable (or the true solution can not be represented in the precision of $(eltype(integrator.u)).", verbose, :dt_epsilon)
             end
             return ReturnCode.Unstable
         end
