@@ -5,23 +5,23 @@ Statistics from the differential equation solver about the solution process.
 
 ## Fields
 
-  - nf: Number of function evaluations. If the differential equation is a split function,
+  - `nf`: Number of function evaluations. If the differential equation is a split function,
     such as a `SplitFunction` for implicit-explicit (IMEX) integration, then `nf` is the
     number of function evaluations for the first function (the implicit function)
-  - nf2: If the differential equation is a split function, such as a `SplitFunction`
+  - `nf2`: If the differential equation is a split function, such as a `SplitFunction`
     for implicit-explicit (IMEX) integration, then `nf2` is the number of function
     evaluations for the second function, i.e. the function treated explicitly. Otherwise
     it is zero.
-  - nw: The number of W=I-gamma*J (or W=I/gamma-J) matrices constructed during the solving
-    process.
-  - nsolve: The number of linear solves `W\\b` required for the integration.
-  - njacs: Number of Jacobians calculated during the integration.
-  - nnonliniter: Total number of iterations for the nonlinear solvers.
-  - nnonlinconvfail: Number of nonlinear solver convergence failures.
-  - ncondition: Number of calls to the condition function for callbacks.
-  - naccept: Number of accepted steps.
-  - nreject: Number of rejected steps.
-  - maxeig: Maximum eigenvalue over the solution. This is only computed if the
+  - `nw`: The number of `W=I-gamma*J` (or `W=I/gamma-J`) matrices constructed
+    during the solving process.
+  - `nsolve`: The number of linear solves `W\\b` required for the integration.
+  - `njacs`: Number of Jacobians calculated during the integration.
+  - `nnonliniter`: Total number of iterations for the nonlinear solvers.
+  - `nnonlinconvfail`: Number of nonlinear solver convergence failures.
+  - `ncondition`: Number of calls to the condition function for callbacks.
+  - `naccept`: Number of accepted steps.
+  - `nreject`: Number of rejected steps.
+  - `maxeig`: Maximum eigenvalue over the solution. This is only computed if the
     method is an auto-switching algorithm.
 """
 mutable struct DEStats
