@@ -9,7 +9,7 @@ const NONCONCRETE_ELTYPE_MESSAGE = """
                                    all the same. If this was intentional, for example,
                                    using Unitful.jl with different unit values, then use
                                    an array type which has fast broadcast support for
-                                   heterogeneous values such as the ArrayPartition
+                                   heterogeneous values such as the `ArrayPartition`
                                    from RecursiveArrayTools.jl. For example:
 
                                    ```julia
@@ -109,6 +109,21 @@ function checkkwargs(kwargshandle; kwargs...)
     end
 end
 
+function checkkwargs(kwargshandle, allowed; kwargs...)
+    if any(x -> x ∉ allowed, keys(kwargs))
+        if kwargshandle == KeywordArgError
+            throw(CommonKwargError(kwargs))
+        elseif kwargshandle == KeywordArgWarn
+            @warn KWARGWARN_MESSAGE
+            unrecognized = setdiff(keys(kwargs), allowed)
+            print("Unrecognized keyword arguments: ")
+            printstyled(unrecognized; bold = true, color = :red)
+            print("\n\n")
+        else
+            @assert kwargshandle == KeywordArgSilent
+        end
+    end
+end
 """
     $(TYPEDSIGNATURES)
 
